@@ -21,6 +21,11 @@ c
       implicit none
 c----      include 'Zearth.h'
 #include  "Zearth.h"
+#include  "Zatmos.h"
+#include  "Ztrack.h"
+#include  "Ztrackp.h"
+#include  "Ztrackv.h"
+
       real*8 z, cosz, tin, leng, t
       integer jcut
 c
@@ -60,6 +65,8 @@ c
 c
       real*8 f1, f2, int1, int2,  rp, clenbetween2h
       real*8 cvh2denp, cvh2den2p, rho, rhop, d, cvh2thick
+      real*8 ct2lTA
+
       real*8 nearv/0.5/, nearv2/0.99/, t1, t2
       integer i
 
@@ -109,15 +116,18 @@ c               max movable thickness
             jcut =1
          endif
 c     
-         rho = cvh2den(z)
-         rhop = cvh2denp(z)
-c               at very high altitude,  rhop = 0
-         if(cosz .le. 0.d0 .or. rhop .eq. 0.)  then
-            s = t/rho     !  length if density is const.
+         if(OneDim .eq. 1 .and. z .lt. Htop) then
+            leng = ct2lTA(z,  t)
          else
-            d = rho**2 - 2* rhop *cosz * t
-            s = (rho -sqrt(d) )/ rhop/cosz
-         endif
+            rho = cvh2den(z)
+            rhop = cvh2denp(z)
+c               at very high altitude,  rhop = 0
+            if(cosz .le. 0.d0 .or. rhop .eq. 0.)  then
+               s = t/rho        !  length if density is const.
+            else
+               d = rho**2 - 2* rhop *cosz * t
+               s = (rho -sqrt(d) )/ rhop/cosz
+            endif
 
 c\\\\\\
 c       write(*, *) " original depth =", cvh2thick(z)
@@ -125,11 +135,11 @@ c      write(*, *) ' initial guess length =',  s, ' m'
 c\\\\\
 
       
-         if(rhop .ne. 0.) then
-            do i=1,6
+            if(rhop .ne. 0.) then
+               do i=1,6
 c                 get height and cos at s/2 ahead.
-               cosp = cnewcos(Eradius+z, cosz, s/2)
-               zp = cnewh(Eradius+z, cosz, s/2) - Eradius
+                  cosp = cnewcos(Eradius+z, cosz, s/2)
+                  zp = cnewh(Eradius+z, cosz, s/2) - Eradius
 c                 write(0,*) " cosp =", cosp, " height at z-s/2*cos=",zp
 c                 once again
 c                s = t/cvh2den(zp)   !  length if density is const.
@@ -139,15 +149,16 @@ c
 c               expand rho at zp, and get integrals of f and f^2
 c                 [ -s/2 to s/2] ds
 c
-               rp = zp + Eradius
-               int1 = f1(s/2) - f1(-s/2)
-               int2 = f2(s/2) - f2(-s/2)
+                  rp = zp + Eradius
+                  int1 = f1(s/2) - f1(-s/2)
+                  int2 = f2(s/2) - f2(-s/2)
 c                  get new s
-               s = (t - cvh2denp(zp)*int1 - cvh2den2p(zp)*int2/2)
-     *           /  cvh2den(zp) 
-            enddo
+                  s = (t - cvh2denp(zp)*int1 - cvh2den2p(zp)*int2/2)
+     *                 /  cvh2den(zp) 
+               enddo
+               leng = s
+            endif
          endif
-         leng = s
       endif
       end
 
