@@ -41,6 +41,7 @@ c
 
        if(first) then
           call cinippx  ! make sampling table for pp->p+x
+          call cinipipx
           first = .false.
        endif
 c
@@ -263,6 +264,7 @@ c
         record /ptcl/ p, a
         integer nc, icon
         real*8 xp, avpt, ptn, tmsq, u, akmin, akmax
+        logical notfirst  
 c
 
 
@@ -279,7 +281,7 @@ c                                    ptn.  output sampled pt
 
 c            sample leading particle xp with  pt
            tmsq=ptn**2 + p.mass**2
-           call cslpx(p, tmsq, akmin, akmax,  xp, icon)
+           call cslpx(p, tmsq, akmin, akmax,  xp, notfirst, icon)
 
 
            if(icon .eq. 0 .and.  xp-akmin .lt. .2 ) then
@@ -306,7 +308,12 @@ c           convert it to ptx, pty
 c               set pz
         a.fm.p(3) = sqrt(a.fm.p(4)**2 - a.mass**2 - ptn**2)
 c         fix chacge after collision
-        call cfclp(p, xp, a)
+        if(notfirst) then
+c           keep the same charge if the 2nd,3rd coll. inside A.
+c           a.charge = p.charge  ! not needed since a = p
+        else
+           call cfclp(p, xp, a)
+        endif
 c          this may be needed if crot3vec is not called
 c          after cslp; 
 c        call crot3vec(p.fm, a.fm, a.fm)
@@ -333,6 +340,26 @@ c             + intedndx(i)
      *           intendndx(i)
          endif
       end
+      subroutine cxtulnpi(x, ux)
+c           get normalized integral (from 0 to x) for given x
+c           of leading pi (pp-->p)
+c           u for x=0 to 1 step .01
+         implicit none
+         integer i
+         real*8 x, ux
+
+#include "Zcinippxc.h"
+
+c
+         i=x*nx+1.
+
+         if(i .eq. n) then
+             ux=1.
+         else
+             ux=(intendndx2(i+1)-intendndx2(i))* (x*nx - i+1) +
+     *           intendndx2(i)
+         endif
+      end
 c     *****************************************************************
 c     *                                                               *
 c     * cfclp:   fix charge of a leading particle
@@ -364,28 +391,35 @@ c            branch by ptcl kind
         if(k0 .eq. kpion) then
 c                      pion; more inelastic one is 
 c                           more likely chargeexchanged
-            rf=sqrt(1.-xp)
-            if(u .gt. Cepic0*rf) then
+           rf=sqrt(1.-xp)
+c            if(u .gt. Cepic0*rf) then
+c          if(u .gt. 0.3* sqrt(rf) ) then
+          if(u .gt. 0.35* rf ) then
 c                no charge exc.
-               p.charge = 0
-            else
-               if(pj.charge .eq. 0) then
+             p.charge = pj.charge
+          else
+             if(pj.charge .eq. 0) then
 c                   0--> + or -
                 call rndc(u)
                 if(u .lt. .5) then
-                    p.charge = 1
+                   p.charge = 1
                 else
-                    p.charge = -1
+                   p.charge = -1
                 endif
-            else
-c                  charge-->0
-                p.charge = 0
-            endif
-         endif
+             else
+c                 charge-->0 or opposite charge
+                call rndc(u)
+                if(u .lt. rf*0.30) then
+                   p.charge = -pj.charge
+                else
+                   p.charge = 0
+                endif
+             endif
+          endif
       elseif(k0 .eq. kkaon) then
 c                                         kaon
          rf=sqrt(1.-xp)
-         if(u .gt. Cekaon*rf) then
+         if(u .gt. 0.35*rf) then
               p.charge = pj.charge
          else
               p.charge = 0
@@ -413,18 +447,21 @@ c              same charge
          p.charge = 0
       elseif(k0 .eq. kphi) then
          p.charge = 0
+      elseif(k0 .eq. keta) then
+         p.charge = 0
       else
          write(msg,*) ' code=',k0,' undef. in cfclp'
          call cerrorMsg(msg, 0)
       endif
       end
-      subroutine cslpx(pj,  tmsq, akmin, akmax,  x, icon)
+      subroutine cslpx(pj,  tmsq, akmin, akmax,  x, notfirst, icon)
 c           sampling of x 
 c            pj: structure /ptcl/. Input.
 c          tmsq: input.incident transverse mass square after collision.
 c         akmin: input. min x allowed
 c         akmax: input. max x allowedn
 c             x: output.  sampled x
+c       notfirst: output.   becomes t if this is 2nd, 3rd coll. in A
 c          icon:  0  x sampled
 c                 1  x not sampled. kinematically impossible.
 c    **** note ***  If the target is a nucleus and the collision is
@@ -433,10 +470,10 @@ c    changed to  x**SucPw dx to have smaller inelasticity.
 c    (SucPw=1.5 is default;
 c     this corressponds to alfa=2.5 to Date et al's paper.
 c    (PRD1985,vol.32. 619)  This should be 
-c    managed by calling cslpx2 before calling cslpx (every time!!), i.e,
-c    calling cslpx2 is effective only the first next call  to cslpx.
+c    managed by calling cslpx2
 c
       implicit none
+#include "Zcode.h"
 #include  "Zptcl.h"
 #include  "Zmass.h"
 #include "Zcinippxc.h"
@@ -447,7 +484,7 @@ c
        real*8 umin, umax, temp1, temp2
        integer i, icon
        real*8 u
-       logical lessInela/.false./, makeless
+       logical lessInela/.false./, makeless, notfirst
        save lessInela
 
 
@@ -457,21 +494,34 @@ c
              icon=1
          elseif(.not. lessInela) then
 c             cxtuln(x0, ans) ; ans= integral of dn/dx from 0, x0
-             call cxtuln(akmin, umin)
-             call cxtuln(akmax, umax)
+            if(pj.code .ne. knuc) then
+               call cxtulnpi(akmin, umin)
+               call cxtulnpi(akmax, umax)
+            else
+               call cxtuln(akmin, umin)
+               call cxtuln(akmax, umax)
+            endif
 c                  uniform random number should be between
 c                  umin and umax
 
-             call rndc(u)
-             u=(umax-umin)*u + umin
-             i=u*nx +1
-
-             x=(ppsx(i+1) - ppsx(i))*nx*(u- (i-1)*dx)
-     *            + ppsx(i)
-
+            call rndc(u)
+            u=(umax-umin)*u + umin
+            i=u*nx +1
+            if(pj.code .eq. knuc) then
+               x=(ppsx(i+1) - ppsx(i))*nx*(u- (i-1)*dx)
+     *              + ppsx(i)
+            else
+               x=(pipsx(i+1) - pipsx(i))*nx*(u- (i-1)*dx)
+     *              + pipsx(i)
+            endif
          else
             call rndc(u)
-            temp1 = SucPw + 1.
+            if(pj.code .ne. knuc) then
+c                for mesons, make more inelastic
+               temp1 = SucPw + 0.5
+            else
+               temp1 = SucPw + 1.
+            endif
             temp2 = akmin**temp1
             x = ( (akmax**temp1 - temp2 )*u + temp2 )**(1./temp1)
          endif
@@ -480,6 +530,7 @@ c                  umin and umax
          else
             icon=0
          endif
+         notfirst = lessInela
          return
 c     ************ call this before 2nd, 3rd coll. inside nucleus
 c                  with .true.  and  after that, call with .false.
