@@ -40,7 +40,7 @@ c--------------------------------------------------
       common /regimC/ xregimC(4),signa
       common /percoC/ iperco
       common /encoteC/ etest,tnkte
-     *      /nucpar/cddt
+     *      /nucparC/cddt
       common /probaC/ jnuc,is1,nq,iq,bit,w(32)
 
 c
@@ -50,12 +50,12 @@ c*** finlspC hadrin final state particle list with kinem. variables
 c*** (number of particles,particle type index,direction cosines,energy
 c*** absolute momentum and in finuc in addit. excitation energy
 c--------------------------------------------------
-     *      /finuc/irn,itrn(60),cxrn(60),cyrn(60),czrn(60),
+     *   /finucC/irn,itrn(60),cxrn(60),cyrn(60),czrn(60),
      *elr(60),plr(60),tv
      *      /finlspC/ir,itr(20),cxr(20),cyr(20),czr(20),
      *el(20),pl(20)
 c      integer*2ich,ibar,k1,k2,nzk,nrk
-      integer*2ich,ibar,k1,k2
+      integer*2 ich,ibar,k1,k2
 c
 c--------------------------------------------------
 c***  particle characteristics: masses, decay width, life time,elect.and
@@ -63,7 +63,7 @@ c*** baryonic charge,decay channel indicees
 c--------------------------------------------------
       common/abltisC/am(110),ga(110),tau(110),ich(110)
      *,ibar(110),k1(110),k2(110)
-     *   /thr/ethr,pthr
+     *   /thrC/ ethr,pthr
       dimension ins(30)
 
       common /eventC/ ievent
@@ -727,7 +727,7 @@ c--------------------------------------------------
       do 10 i=1,ir
 c
 c--------------------------------------------------
-c*** storage of h-n-coll. products into nucleus final state c./finuc/
+c*** storage of h-n-coll. products into nucleus final state c./finucC/
 c*** cut off for kinetic energies less then ethr, push them into ex.en.
 c*** tv
 c--------------------------------------------------
@@ -796,7 +796,7 @@ c--------------------------------------------------
       irn=irn+1
 c
 c--------------------------------------------------
-c*** store the particle characteristics into c./finuc/, then take next
+c*** store the particle characteristics into c./finucC/, then take next
 c*** particle
 c--------------------------------------------------
       itrn(irn)=i1
@@ -887,7 +887,7 @@ c--------------------------------------------------
 c
 c--------------------------------------------------
 c*** take the emitted corresp. nucleon into the final particle table
-c*** c./finuc/ after choice of phi and turning into the lab system
+c*** c./finucC/ after choice of phi and turning into the lab system
 c--------------------------------------------------
       irn=irn+1
       itrn(irn)=8
@@ -957,7 +957,7 @@ c--------------------------------------------------
 c
 c--------------------------------------------------
 c*** take the emitted corresp. nucleon into the final particle table
-c*** c./finuc/ after chi ce of phi and turning into the lab system
+c*** c./finucC/ after chi ce of phi and turning into the lab system
 c--------------------------------------------------
       irn=irn+1
       itrn(irn)=1
