@@ -21,6 +21,10 @@ c        reset parameters.
          BorderHeightH = HeightOfInj
       endif
 
+      if(DestEventNo(2) .le. 0) then
+         DestEventNo(2) = DestEventNo(1)
+      endif
+
       if(Cont) then
 c           restore status at the end of previous run
          call crestoreStatus
