@@ -1,3 +1,4 @@
+#include "ctemplCeren.f"
 #include "ZcosmosBD.h"
 c  *************************************** hook for Beginning of a Run
 c  * At this moment, all (system-level) initialization for this run
@@ -7,7 +8,9 @@ c  *
       subroutine chookBgRun
       implicit none
 #include "Zmanagerp.h"
-
+#include "Zcode.h"
+#include "Zptcl.h"
+      record /ptcl/ temp
 c          ///////////
       common /testcos/sumg, ng, nth, nev
       real*8 sumg
@@ -24,6 +27,8 @@ c         Also you may comment out all output routines below.
 
       ieeer = ieee_handler('set', 'invalid', csigHandler)
 #endif
+      call cmkptc(kkaon, 0, 0, temp)
+      write(*,*)  temp.code, temp.subcode
 
 c
 c            namelist output
@@ -87,10 +92,17 @@ c                                 outer boundery.
 c                           2 ==> reached at an observation level
 c                           3 ==> reached at inner boundery.
       record /track/ aTrack
+      record /coord/ angle, tetafai
+
+c     //////////////
+
+
+
 c          ///////////
       common /testcos/sumg, ng, nth, nev
       real*8 sumg
-      integer ng, nth, nev
+      character*8 ptclid
+      integer ng, nth, nev, iij
 c//////////////
 
 
@@ -98,16 +110,22 @@ c
 c     For id =2, you need not output the z value, because it is always
 c     0 (within the computational accuracy).
 c
-      if(id .eq. 2 .and. aTrack.p.code .eq. kmuon ) then
-c      if(id .eq. 2 ) then
+c      if(id .eq. 2 .and. aTrack.p.code .eq. kmuon ) then
+      if(id .eq. 3 .or. id .eq. 2) then
+c          iij = aTrack.p.code  
+c          call cgpid(iij, ptclid)
+c      if(id .eq. 2 .and. aTrack.p.code .eq. kelec ) then
 c            output typical quantities.
-        write(*, *) 
+         call cqIncident(inci, angle)
+          write(*, *) id,  nev, 
      *  aTrack.where,   !  observation level. integer*2.  1 is highest.
-c     *  aTrack.p.code,    !  ptcl code.  integer*2.
+c     *  aTrack.p.code, " ", ptclid,    !  ptcl code.  integer*2.
+     *  aTrack.p.code,
 c     *  aTrack.p.charge,  !  charge,  integer*2 
 c     *  sngl(aTrack.t), !  relateive arrival time in nsec (NOT sec).
 c                        !  if TimeStructure is F, nonsense.
-     *  sngl(aTrack.p.fm.e) ! total energy in GeV.
+     *  sngl(aTrack.p.fm.e), ! total energy in GeV.
+     *  sngl(-angle.r(3))
 c     *  sngl(aTrack.pos.xyz.x), sngl(aTrack.pos.xyz.y)  !  x, y in m
 c     *  sngl(aTrack.vec.w.x),  ! direc. cos.x in the current detector system.
 c     *  sngl(aTrack.vec.w.y),  ! direc. cos.y
@@ -153,6 +171,7 @@ c    *
       record /track/ inci
       record /coord/ angle, tetafai
       integer i
+
 c          ///////////
       common /testcos/sumg, ng, nth, nev
       real*8 sumg
@@ -160,7 +179,8 @@ c          ///////////
       real*8  fdepth, bsin, teta, fai, sumsize
       real*8  cgetBsin
 c     //////////////
-
+c      call cqIncident(inci, angle)
+c      write(*,*) inci.vec.coszenith, angle.r(3)
       if(ObserveAS) then
          call cqFirstID(fdepth)
          fdepth = fdepth * 0.1         ! in g/cm2
@@ -186,7 +206,7 @@ c         write(*, *) (ASObsSites(i).age,   i=1, NoOfASSites)
      *           sngl(bsin), sngl(sumsize), sngl(teta), sngl(fai)  
          enddo
       endif
-      write(*, *)
+c      write(*, *)
       end
 
 
@@ -336,8 +356,6 @@ c        IntInfArray(ProcessNo).process  will have
 c             'col' or 'decay'
       end
 
-      
-
 
 
 
